@@ -21,9 +21,8 @@
 #ifndef KTIPFILTERPLUGIN_H
 #define KTIPFILTERPLUGIN_H
 
+#include <QTimer>
 #include <interfaces/plugin.h>
-#include <interfaces/ipblockinginterface.h>
-
 #include "ipblockingprefpage.h"
 #include "antip2p.h"
 
@@ -33,21 +32,24 @@ namespace kt
 {	
 	class IPBlockingPrefPage;
 	
+	const int AUTO_UPDATE_RETRY_INTERVAL = 15*60; // seconds
+	
 	/**
 	 * @author Ivan Vasic <ivasic@gmail.com>
 	 * @brief IP filter plugin
 	 * 
 	 * This plugin will load IP ranges from specific files into KT IPBlocklist.
 	 */
-	class IPFilterPlugin : public Plugin, public kt::IPBlockingInterface
+	class IPFilterPlugin : public Plugin
 	{
 		Q_OBJECT
 	public:
-		IPFilterPlugin(QObject* parent, const char* name, const QStringList& args);
+		IPFilterPlugin(QObject* parent, const QStringList& args);
 		virtual ~IPFilterPlugin();
 
 		virtual void load();
 		virtual void unload();
+		virtual bool versionCheck(const QString & version) const;
 		
 		///Loads the KT format list filter
 		void loadFilters();
@@ -58,14 +60,17 @@ namespace kt
 		///Unloads the anti-p2p filter list
 		bool unloadAntiP2P();
 		
+		/// Whether or not the IP filter is loaded and running
+		bool loadedAndRunning(); 
 		
-		///Checks if IP is listed in AntiP2P filter list.
-		bool isBlockedIP(const QString& ip);
+	public slots:
+		void checkAutoUpdate();
+		void notification(const QString & msg);
 		
-		bool versionCheck(const QString & version) const;
 	private:
 		IPBlockingPrefPage* pref;
 		AntiP2P* level1;
+		QTimer auto_update_timer;
 	};
 
 }
